@@ -51,7 +51,7 @@ def remote_call(remote_endpoint):
             recv_data = sock.recv(4096)
             current_app.logger.debug('recv_data: %s', recv_data)
             if not recv_data:
-                yield '<pre>rtserver closed</pre>'
+                yield '<pre>gourd server closed</pre>'
                 if unique_id in socket_map:
                     socket_map.pop(unique_id).close()
                 break
